@@ -22,6 +22,7 @@ licence['en']="""
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+python3safe=True
 import os.path, sqlite3, subprocess
 import version
 from globaldef import userShareDir
@@ -61,7 +62,7 @@ def checkVersion(major, minor):
     else:
         major, minor = values
         if major < version.major():
-            raise KeyError, "The database version is too old!"
+            raise KeyError("The database version is too old!")
         elif minor < version.minor():
             cursor.execute("""update version
                           set minor=?
