@@ -161,14 +161,14 @@ p, li { white-space: pre-wrap; }
         <translation>Continue...</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="280"/>
+        <location filename="../mainWindow.py" line="282"/>
         <source>Double-clic non pris en compte</source>
         <translation>Double click is ignored</translation>
     </message>
     <message>
         <location filename="../mainWindow.py" line="280"/>
         <source>pas d&apos;action pour l&apos;attribut %1</source>
-        <translation>No action for attribute &quot;%1&quot;</translation>
+        <translation type="obsolete">No action for attribute &quot;%1&quot;</translation>
     </message>
     <message>
         <location filename="../mainWindow.py" line="7274270"/>
@@ -186,7 +186,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">No selected file</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="477"/>
+        <location filename="../mainWindow.py" line="485"/>
         <source>Veuillez choisir au moins un fichier</source>
         <translation>Please choose at least one file</translation>
     </message>
@@ -201,7 +201,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Choose files to copy from the pluggable media</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="473"/>
+        <location filename="../mainWindow.py" line="481"/>
         <source>Choix de la destination ...</source>
         <translation>Choose destination...</translation>
     </message>
@@ -211,7 +211,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Choose a destination directory</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="516"/>
+        <location filename="../mainWindow.py" line="524"/>
         <source>Voir les copies</source>
         <translation>See the copies</translation>
     </message>
@@ -221,12 +221,12 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Do you want to see the copied files?</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="524"/>
+        <location filename="../mainWindow.py" line="532"/>
         <source>Destination manquante</source>
         <translation>Missing destination</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="524"/>
+        <location filename="../mainWindow.py" line="532"/>
         <source>Veuillez choisir une destination pour la copie des fichiers</source>
         <translation>Please choose a destination to copy the files</translation>
     </message>
@@ -341,7 +341,7 @@ p, li { white-space: pre-wrap; }
         <translation>Homework</translation>
     </message>
     <message>
-        <location filename="../copyToDialog1.py" line="162"/>
+        <location filename="../copyToDialog1.py" line="164"/>
         <source>%s kilo-octets</source>
         <translation>%S kBytes</translation>
     </message>
@@ -351,7 +351,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">%s MBytes</translation>
     </message>
     <message>
-        <location filename="../copyToDialog1.py" line="168"/>
+        <location filename="../copyToDialog1.py" line="170"/>
         <source>%s giga-octets</source>
         <translation>%s GBytes</translation>
     </message>
@@ -363,7 +363,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../ownedUsbDisk.py" line="212"/>
         <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
-        <translation>The medium %1&lt;br&gt;is unknown, please give the owner&apos;s name</translation>
+        <translation type="obsolete">The medium %1&lt;br&gt;is unknown, please give the owner&apos;s name</translation>
     </message>
     <message>
         <location filename="../ownedUsbDisk.py" line="213"/>
@@ -371,7 +371,7 @@ p, li { white-space: pre-wrap; }
         <translation>Enter a name</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="422"/>
+        <location filename="../mainWindow.py" line="430"/>
         <source>Vous allez effacer plusieurs baladeurs</source>
         <translation>You will erase many drives</translation>
     </message>
@@ -403,7 +403,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../preferences.py" line="53"/>
         <source>%1 secondes</source>
-        <translation>%1 seconds</translation>
+        <translation type="obsolete">%1 seconds</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../Ui_chooseInSticks.py" line="163"/>
@@ -416,14 +416,14 @@ p, li { white-space: pre-wrap; }
         <translation>Add a filename or a filter defined in the edit line</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="547"/>
+        <location filename="../mainWindow.py" line="555"/>
         <source>Réitérer la dernière commande</source>
         <translation>Redo the last command</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../mainWindow.py" line="547"/>
         <source>La dernière commande était&lt;br&gt;%1&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
-        <translation>The last command was&lt;br&gt;%1&lt;br&gt;Do you want to redo it with the new media?</translation>
+        <translation type="obsolete">The last command was&lt;br&gt;%1&lt;br&gt;Do you want to redo it with the new media?</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../Ui_preferences.py" line="126"/>
@@ -440,6 +440,206 @@ p, li { white-space: pre-wrap; }
         <source>Si la case est cochée, les données sont transférées sur le disque dur puis effacée des baladeurs.</source>
         <translation>If this box is checked, data are transferred to the disk, then delete from the pluggable media.</translation>
     </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="117"/>
+        <source>Choix d&apos;un groupe d&apos;élèves</source>
+        <translation>Choose a students group</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="120"/>
+        <source>Actions</source>
+        <translation>Actions</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="121"/>
+        <source>Replier toutes les classes</source>
+        <translation>Fold down checkboxes</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="122"/>
+        <source>Tout replier</source>
+        <translation>Fold down everything</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="123"/>
+        <source>Cocher tous les élèves visibles</source>
+        <translation>Check any visible student&apos;s box</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="124"/>
+        <source>Cocher</source>
+        <translation>Check the box</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="125"/>
+        <source>Décocher tous les élèves, visibles ou non</source>
+        <translation>Unchez every student&apos;s box, either visible or not</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="126"/>
+        <source>Décocher</source>
+        <translation>Uncheck box</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="128"/>
+        <source>Ajout à la liste</source>
+        <translation>Add to the list</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="130"/>
+        <source>Suppr. de la liste</source>
+        <translation>Del from the list</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="135"/>
+        <source>Valider</source>
+        <translation>Validate</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="132"/>
+        <source>N° à partir de</source>
+        <translation>Number from</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="131"/>
+        <source>Quand la case est cochée, un numéro sera ajouté comme préfixe aux noms</source>
+        <translation>When the box is checked, a number will be prepended to names</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="133"/>
+        <source>La numérotation commence à cette valeur</source>
+        <translation>Numbering begins there</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="127"/>
+        <source>Ajouter les noms cochés de l&apos;arbre dans la liste à droite</source>
+        <translation>Add checked names from the tree to the list on the right</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="129"/>
+        <source>Supprimer de la liste les noms en surbrillance</source>
+        <translation>Delete the list of highlighted names</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="134"/>
+        <source>Accepter la liste actuelle et fermer ce dialogue</source>
+        <translation>Accept the current list and close this dialog</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="136"/>
+        <source>Supprimer tous les noms de la liste et fermer ce dialogue</source>
+        <translation>Delete all the names from the list and close this dialog</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="137"/>
+        <source>Remettre à zéro</source>
+        <translation>Reset</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../ownedUsbDisk.py" line="70"/>
+        <source>Choix du propriétaire</source>
+        <translation>Choose the owner</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../ownedUsbDisk.py" line="71"/>
+        <source>Nouveau nom du propriétaire du baladeur</source>
+        <translation>New name of the drive&apos;s owner</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="118"/>
+        <source>Liste d&apos;élèves</source>
+        <translation>List of students</translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="119"/>
+        <source>Ouvrir un fichier ...</source>
+        <translation>Open a file...</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="134"/>
+        <source>Fichier des élèves :</source>
+        <translation>File of students:</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="72"/>
+        <source>Nommer le baladeur nouvellement connecté</source>
+        <translation>Give a name to the recently connected drive</translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="73"/>
+        <source>Changez le choix parmi cette liste si une autre ligne convient mieux</source>
+        <translation>Choose another line in the list if it fits better</translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="75"/>
+        <source>nom actuel du baladeur</source>
+        <translation>current name of the drive</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="76"/>
+        <source>C&apos;est le nom connu par votre ordinateur, s&apos;il a déjà été défini dans le passé</source>
+        <translation>It is the name your computer knowed, if it was defined in the past</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="77"/>
+        <source>nom proposé</source>
+        <translation>proposed name</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="78"/>
+        <source>Le nouveau nom proposé peut venir de la liste à gauche ou être modifié à la main</source>
+        <translation>The proposed name can be taken from the list at the left side or be typed in</translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="79"/>
+        <source>Renommer le baladeur</source>
+        <translation>Rename the drive</translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="80"/>
+        <source>Choisir comme nouveau nom</source>
+        <translation>Choose as a new name</translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="81"/>
+        <source>Fermer le dialogue sans rien faire</source>
+        <translation>Close the dialog without doing anything</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="82"/>
+        <source>Échappement</source>
+        <translation>Escape</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../choixEleves.py" line="96"/>
+        <source>Échec à l&apos;ouverture du fichier élèves</source>
+        <translation>Failed to open students&apos; file</translation>
+    </message>
+    <message>
+        <location filename="../ownedUsbDisk.py" line="212"/>
+        <source>La cle {id}&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
+        <translation>The drive {id}&lt;br&gt;is not identified, give the owner&apos;s name</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../choixEleves.py" line="96"/>
+        <source>Le fichier {schoolfile} n&apos;a pas pu être traité : {erreur}</source>
+        <translation>The file{schoolfile} could not be managed : {erreur} </translation>
+    </message>
+    <message>
+        <location filename="../preferences.py" line="55"/>
+        <source>{t} secondes</source>
+        <translation>{t} seconds</translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="282"/>
+        <source>pas d&apos;action pour l&apos;attribut {a}</source>
+        <translation>No action for attribute {a}</translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="555"/>
+        <source>La dernière commande était&lt;br&gt;{cmd}&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
+        <translation>Last command was&lt;br&gt;{cmd}&lt;br&gt;Do you want to lauch it again with the new drives?</translation>
+    </message>
     <message encoding="UTF-8">
         <location filename="../Ui_chooseInSticks.py" line="142"/>
         <source>Choix de fichiers à supprimer</source>
@@ -490,21 +690,6 @@ p, li { white-space: pre-wrap; }
         <source>Rechercher (répertoire) ...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="122"/>
-        <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="123"/>
-        <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="127"/>
-        <source>Répertoire pour les travaux :</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message encoding="UTF-8">
         <location filename="../Ui_copyToDialog1.py" line="174"/>
         <source>Choix des fichiers à copier</source>
@@ -526,218 +711,53 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="415"/>
-        <source>Choix de fichiers à supprimer (jokers autorisés)</source>
+        <location filename="../Ui_preferences.py" line="122"/>
+        <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="477"/>
-        <source>Aucun fichier sélectionné</source>
+        <location filename="../Ui_preferences.py" line="123"/>
+        <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="471"/>
-        <source>Choix de fichiers à copier</source>
+        <location filename="../Ui_preferences.py" line="127"/>
+        <source>Répertoire pour les travaux :</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="472"/>
-        <source>Choix de fichiers à copier depuis les baladeurs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="485"/>
-        <source>Choisir un répertoire de destination</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="516"/>
-        <source>Voulez-vous voir les fichiers copiés ?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../copyToDialog1.py" line="165"/>
+        <location filename="../copyToDialog1.py" line="167"/>
         <source>%s méga-octets</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="117"/>
-        <source>Choix d&apos;un groupe d&apos;élèves</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="120"/>
-        <source>Actions</source>
-        <translation type="unfinished">Actions</translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="121"/>
-        <source>Replier toutes les classes</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="122"/>
-        <source>Tout replier</source>
+        <location filename="../mainWindow.py" line="423"/>
+        <source>Choix de fichiers à supprimer (jokers autorisés)</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="123"/>
-        <source>Cocher tous les élèves visibles</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="124"/>
-        <source>Cocher</source>
+        <location filename="../mainWindow.py" line="485"/>
+        <source>Aucun fichier sélectionné</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="125"/>
-        <source>Décocher tous les élèves, visibles ou non</source>
+        <location filename="../mainWindow.py" line="479"/>
+        <source>Choix de fichiers à copier</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="126"/>
-        <source>Décocher</source>
+        <location filename="../mainWindow.py" line="480"/>
+        <source>Choix de fichiers à copier depuis les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="128"/>
-        <source>Ajout à la liste</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="130"/>
-        <source>Suppr. de la liste</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="135"/>
-        <source>Valider</source>
+        <location filename="../mainWindow.py" line="493"/>
+        <source>Choisir un répertoire de destination</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="132"/>
-        <source>N° à partir de</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="131"/>
-        <source>Quand la case est cochée, un numéro sera ajouté comme préfixe aux noms</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="133"/>
-        <source>La numérotation commence à cette valeur</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="127"/>
-        <source>Ajouter les noms cochés de l&apos;arbre dans la liste à droite</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="129"/>
-        <source>Supprimer de la liste les noms en surbrillance</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="134"/>
-        <source>Accepter la liste actuelle et fermer ce dialogue</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="136"/>
-        <source>Supprimer tous les noms de la liste et fermer ce dialogue</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="137"/>
-        <source>Remettre à zéro</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../ownedUsbDisk.py" line="70"/>
-        <source>Choix du propriétaire</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../ownedUsbDisk.py" line="71"/>
-        <source>Nouveau nom du propriétaire du baladeur</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="118"/>
-        <source>Liste d&apos;élèves</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_choixEleves.py" line="119"/>
-        <source>Ouvrir un fichier ...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="134"/>
-        <source>Fichier des élèves :</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="72"/>
-        <source>Nommer le baladeur nouvellement connecté</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_nameAdrive.py" line="73"/>
-        <source>Changez le choix parmi cette liste si une autre ligne convient mieux</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_nameAdrive.py" line="75"/>
-        <source>nom actuel du baladeur</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="76"/>
-        <source>C&apos;est le nom connu par votre ordinateur, s&apos;il a déjà été défini dans le passé</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="77"/>
-        <source>nom proposé</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="78"/>
-        <source>Le nouveau nom proposé peut venir de la liste à gauche ou être modifié à la main</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_nameAdrive.py" line="79"/>
-        <source>Renommer le baladeur</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_nameAdrive.py" line="80"/>
-        <source>Choisir comme nouveau nom</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../Ui_nameAdrive.py" line="81"/>
-        <source>Fermer le dialogue sans rien faire</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="82"/>
-        <source>Échappement</source>
-        <translation type="unfinished">Escape</translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../choixEleves.py" line="94"/>
-        <source>Échec à l&apos;ouverture du fichier élèves</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../choixEleves.py" line="94"/>
-        <source>Le fichier %1 n&apos;a pas pu être traité</source>
+        <location filename="../mainWindow.py" line="524"/>
+        <source>Voulez-vous voir les fichiers copiés ?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -794,52 +814,52 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Version #%1.%2</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="799"/>
+        <location filename="../mainWindow.py" line="806"/>
         <source>Cocher ou décocher cette case en cliquant.&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour agir sur plusieurs baladeurs.</source>
         <translation>Check or uncheck this box bi a click&lt;br&gt;&lt;b&gt;Double click&lt;/b&gt; to modifiy several media.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../help.py" line="41"/>
-        <source>Version numéro %1.%2</source>
-        <translation type="unfinished"></translation>
+        <location filename="../help.py" line="43"/>
+        <source>Version numéro {major}.{minor}</source>
+        <translation>Version number {major}.{minor}</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="581"/>
+        <location filename="../mainWindow.py" line="589"/>
         <source>Démontage des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="581"/>
+        <location filename="../mainWindow.py" line="589"/>
         <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="801"/>
+        <location filename="../mainWindow.py" line="808"/>
         <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="803"/>
+        <location filename="../mainWindow.py" line="810"/>
         <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="805"/>
+        <location filename="../mainWindow.py" line="812"/>
         <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="807"/>
+        <location filename="../mainWindow.py" line="814"/>
         <source>Fabricant de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="809"/>
+        <location filename="../mainWindow.py" line="816"/>
         <source>Modèle de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="811"/>
+        <location filename="../mainWindow.py" line="818"/>
         <source>Numéro de série de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -942,12 +962,12 @@ p, li { white-space: pre-wrap; }
         <translation>Preferences</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="201"/>
+        <location filename="../mainWindow.py" line="203"/>
         <source>Refaire à nouveau</source>
         <translation>Redo last command</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="202"/>
+        <location filename="../mainWindow.py" line="204"/>
         <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
         <translation>Redo the last successful command, with newly connected medias</translation>
     </message>
@@ -972,24 +992,24 @@ p, li { white-space: pre-wrap; }
         <translation>Delete files or directories in selected medias</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="203"/>
+        <location filename="../mainWindow.py" line="205"/>
         <source>Arrêter les opérations en cours</source>
         <translation>Stop ongoing operations</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="204"/>
+        <location filename="../mainWindow.py" line="206"/>
         <source>Essaie d&apos;arrêter les opérations en cours. À faire seulement si celles-ci durent trop longtemps</source>
         <translation>Try to stop ongoing operations. To do only if they are too slow</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="77"/>
+        <location filename="../mainWindow.py" line="81"/>
         <source>&lt;br /&gt;Des noms sont disponibles pour renommer les prochains baladeurs que vous brancherez</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;br /&gt;Names are availble to rename next drives you will plug in</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="78"/>
+        <location filename="../mainWindow.py" line="82"/>
         <source>&lt;br /&gt;Cliquez sur ce bouton pour préparer une liste de noms afin de renommer les prochains baladeurs que vous brancherez</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;br /&gt;Click on this button to prepare a list of names to rename drives you will plug in later</translation>
     </message>
 </context>
 <context>
@@ -1053,25 +1073,25 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Used size: %1 kBytes</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="49"/>
-        <source>Place totale : %1 kilo-octets</source>
-        <translation type="unfinished"></translation>
+        <location filename="../diskFull.py" line="51"/>
+        <source>Place totale : {size} kilo-octets</source>
+        <translation>Total size: {size} kilobytes</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="50"/>
-        <source>Place utilisée : %1 kilo-octets</source>
-        <translation type="unfinished"></translation>
+        <location filename="../diskFull.py" line="52"/>
+        <source>Place utilisée : {size} kilo-octets</source>
+        <translation>Used: {size} kilobytes</translation>
     </message>
 </context>
 <context>
     <name>uDisk</name>
     <message>
-        <location filename="../usbDisk.py" line="63"/>
+        <location filename="../usbDisk.py" line="65"/>
         <source>point de montage</source>
         <translation>Mount point</translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="64"/>
+        <location filename="../usbDisk.py" line="66"/>
         <source>taille</source>
         <translation>Size</translation>
     </message>
@@ -1091,7 +1111,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Serial number</translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="70"/>
+        <location filename="../usbDisk.py" line="72"/>
         <source>cocher</source>
         <translation>Check</translation>
     </message>
@@ -1101,17 +1121,17 @@ p, li { white-space: pre-wrap; }
         <translation>Owner</translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="65"/>
+        <location filename="../usbDisk.py" line="67"/>
         <source>marque</source>
         <translation>vendor</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../usbDisk.py" line="66"/>
+        <location filename="../usbDisk.py" line="68"/>
         <source>modèle de disque</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../usbDisk.py" line="67"/>
+        <location filename="../usbDisk.py" line="69"/>
         <source>numéro de série</source>
         <translation type="unfinished"></translation>
     </message>
