@@ -121,37 +121,32 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="280"/>
+        <location filename="../mainWindow.py" line="282"/>
         <source>Double-clic non pris en compte</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="280"/>
-        <source>pas d&apos;action pour l&apos;attribut %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainWindow.py" line="477"/>
+        <location filename="../mainWindow.py" line="485"/>
         <source>Veuillez choisir au moins un fichier</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="473"/>
+        <location filename="../mainWindow.py" line="481"/>
         <source>Choix de la destination ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="516"/>
+        <location filename="../mainWindow.py" line="524"/>
         <source>Voir les copies</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="524"/>
+        <location filename="../mainWindow.py" line="532"/>
         <source>Destination manquante</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="524"/>
+        <location filename="../mainWindow.py" line="532"/>
         <source>Veuillez choisir une destination pour la copie des fichiers</source>
         <translation type="unfinished"></translation>
     </message>
@@ -181,12 +176,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../copyToDialog1.py" line="162"/>
+        <location filename="../copyToDialog1.py" line="164"/>
         <source>%s kilo-octets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../copyToDialog1.py" line="168"/>
+        <location filename="../copyToDialog1.py" line="170"/>
         <source>%s giga-octets</source>
         <translation type="unfinished"></translation>
     </message>
@@ -198,7 +193,7 @@
     <message>
         <location filename="../ownedUsbDisk.py" line="212"/>
         <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
-        <translation>La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
+        <translation type="obsolete">La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
     </message>
     <message>
         <location filename="../ownedUsbDisk.py" line="213"/>
@@ -206,7 +201,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="422"/>
+        <location filename="../mainWindow.py" line="430"/>
         <source>Vous allez effacer plusieurs baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
@@ -296,37 +291,37 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="415"/>
+        <location filename="../mainWindow.py" line="423"/>
         <source>Choix de fichiers à supprimer (jokers autorisés)</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="477"/>
+        <location filename="../mainWindow.py" line="485"/>
         <source>Aucun fichier sélectionné</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="471"/>
+        <location filename="../mainWindow.py" line="479"/>
         <source>Choix de fichiers à copier</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="472"/>
+        <location filename="../mainWindow.py" line="480"/>
         <source>Choix de fichiers à copier depuis les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="485"/>
+        <location filename="../mainWindow.py" line="493"/>
         <source>Choisir un répertoire de destination</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="516"/>
+        <location filename="../mainWindow.py" line="524"/>
         <source>Voulez-vous voir les fichiers copiés ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../copyToDialog1.py" line="165"/>
+        <location filename="../copyToDialog1.py" line="167"/>
         <source>%s méga-octets</source>
         <translation type="unfinished"></translation>
     </message>
@@ -355,11 +350,6 @@ p, li { white-space: pre-wrap; }
         <source>30 secondes</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../preferences.py" line="53"/>
-        <source>%1 secondes</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message encoding="UTF-8">
         <location filename="../Ui_chooseInSticks.py" line="163"/>
         <source>Ligne d&apos;édition du nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
@@ -371,15 +361,10 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="547"/>
+        <location filename="../mainWindow.py" line="555"/>
         <source>Réitérer la dernière commande</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="547"/>
-        <source>La dernière commande était&lt;br&gt;%1&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message encoding="UTF-8">
         <location filename="../Ui_preferences.py" line="126"/>
         <source>Efface les fichiers et les répertoires après copie</source>
@@ -566,68 +551,88 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../choixEleves.py" line="94"/>
+        <location filename="../choixEleves.py" line="96"/>
         <source>Échec à l&apos;ouverture du fichier élèves</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../ownedUsbDisk.py" line="212"/>
+        <source>La cle {id}&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message encoding="UTF-8">
-        <location filename="../choixEleves.py" line="94"/>
-        <source>Le fichier %1 n&apos;a pas pu être traité</source>
+        <location filename="../choixEleves.py" line="96"/>
+        <source>Le fichier {schoolfile} n&apos;a pas pu être traité : {erreur}</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../preferences.py" line="55"/>
+        <source>{t} secondes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainWindow.py" line="282"/>
+        <source>pas d&apos;action pour l&apos;attribut {a}</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="555"/>
+        <source>La dernière commande était&lt;br&gt;{cmd}&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context encoding="UTF-8">
     <name>Main</name>
     <message encoding="UTF-8">
-        <location filename="../help.py" line="41"/>
-        <source>Version numéro %1.%2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="581"/>
+        <location filename="../mainWindow.py" line="589"/>
         <source>Démontage des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="581"/>
+        <location filename="../mainWindow.py" line="589"/>
         <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="801"/>
+        <location filename="../mainWindow.py" line="808"/>
         <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="803"/>
+        <location filename="../mainWindow.py" line="810"/>
         <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="805"/>
+        <location filename="../mainWindow.py" line="812"/>
         <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="807"/>
+        <location filename="../mainWindow.py" line="814"/>
         <source>Fabricant de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="809"/>
+        <location filename="../mainWindow.py" line="816"/>
         <source>Modèle de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="811"/>
+        <location filename="../mainWindow.py" line="818"/>
         <source>Numéro de série de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="799"/>
+        <location filename="../mainWindow.py" line="806"/>
         <source>Cocher ou décocher cette case en cliquant.&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour agir sur plusieurs baladeurs.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message encoding="UTF-8">
+        <location filename="../help.py" line="43"/>
+        <source>Version numéro {major}.{minor}</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -702,12 +707,12 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="201"/>
+        <location filename="../mainWindow.py" line="203"/>
         <source>Refaire à nouveau</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="202"/>
+        <location filename="../mainWindow.py" line="204"/>
         <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
         <translation type="unfinished"></translation>
     </message>
@@ -732,22 +737,22 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="203"/>
+        <location filename="../mainWindow.py" line="205"/>
         <source>Arrêter les opérations en cours</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="204"/>
+        <location filename="../mainWindow.py" line="206"/>
         <source>Essaie d&apos;arrêter les opérations en cours. À faire seulement si celles-ci durent trop longtemps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="77"/>
+        <location filename="../mainWindow.py" line="81"/>
         <source>&lt;br /&gt;Des noms sont disponibles pour renommer les prochains baladeurs que vous brancherez</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="78"/>
+        <location filename="../mainWindow.py" line="82"/>
         <source>&lt;br /&gt;Cliquez sur ce bouton pour préparer une liste de noms afin de renommer les prochains baladeurs que vous brancherez</source>
         <translation type="unfinished"></translation>
     </message>
@@ -803,30 +808,30 @@ p, li { white-space: pre-wrap; }
 <context encoding="UTF-8">
     <name>diskFull</name>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="49"/>
-        <source>Place totale : %1 kilo-octets</source>
+        <location filename="../diskFull.py" line="51"/>
+        <source>Place totale : {size} kilo-octets</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="50"/>
-        <source>Place utilisée : %1 kilo-octets</source>
+        <location filename="../diskFull.py" line="52"/>
+        <source>Place utilisée : {size} kilo-octets</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>uDisk</name>
     <message>
-        <location filename="../usbDisk.py" line="63"/>
+        <location filename="../usbDisk.py" line="65"/>
         <source>point de montage</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="64"/>
+        <location filename="../usbDisk.py" line="66"/>
         <source>taille</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="70"/>
+        <location filename="../usbDisk.py" line="72"/>
         <source>cocher</source>
         <translation type="unfinished"></translation>
     </message>
@@ -836,17 +841,17 @@ p, li { white-space: pre-wrap; }
         <translation>propriétaire</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../usbDisk.py" line="66"/>
+        <location filename="../usbDisk.py" line="68"/>
         <source>modèle de disque</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../usbDisk.py" line="67"/>
+        <location filename="../usbDisk.py" line="69"/>
         <source>numéro de série</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="65"/>
+        <location filename="../usbDisk.py" line="67"/>
         <source>marque</source>
         <translation type="unfinished"></translation>
     </message>
