@@ -23,6 +23,8 @@ licence['en']="""
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+python3safe=True
+
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 import ownedUsbDisk, help, copyToDialog1, chooseInSticks, usbThread
@@ -51,7 +53,7 @@ def registerCmd(cmd,partition):
     @param partition une partition
     """
     global pastCommands, lastCommand
-    if pastCommands.has_key(cmd):
+    if cmd in pastCommands:
         pastCommands[cmd].append(partition.owner)
     else:
         pastCommands[cmd]=[partition.owner]
@@ -71,6 +73,8 @@ class mainWindow(QMainWindow):
         from Ui_mainWindow  import Ui_MainWindow
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
+        self.copyfromIcon=QIcon("/usr/share/icons/Tango/scalable/actions/back.svg")
+        self.movefromIcon=QIcon("/usr/share/scolasync/images/movefrom.svg")
         # crée le dialogue des nouveaux noms
         self.namesFullIcon=QIcon("/usr/share/icons/Tango/scalable/actions/gtk-find-and-replace.svg")
         self.namesEmptyIcon=QIcon("/usr/share/icons/Tango/scalable/actions/gtk-find.svg")
@@ -86,10 +90,9 @@ class mainWindow(QMainWindow):
         self.proxy.setSourceModel(self.t.model())
         self.opts=opts
         self.timer=QTimer()
-        self.applyPreferences()
         self.listener=deviceListener.DeviceListener(self)
+        self.applyPreferences()
         self.updateButtons()
-        self.availableNames=False # cette variable est regénérée ci-dessous
         self.setAvailableNames(False)
         self.operations=[] # liste des opérations précédemment "réussies"
         self.oldThreads=set() # threads lancés éventuellement encore vivants
@@ -184,7 +187,6 @@ class mainWindow(QMainWindow):
         fonction de rappel pour un medium retiré
         @param s une chaine de caractères du type /dev/sdxy
         """
-        ## print "dans deviceRemoved", s
         if qApp.diskData.hasDev(s):
             self.checkDisks()
         
@@ -242,6 +244,7 @@ class mainWindow(QMainWindow):
         qApp.diskData=other
         self.header=ownedUsbDisk.uDisk.headers(self.checkable)
         self.connectTableModel(other)
+        self.updateButtons()
 
     def changeWd(self, newDir):
         """
@@ -259,7 +262,6 @@ class mainWindow(QMainWindow):
         c=idx.column()
         mappedIdx=self.proxy.mapFromSource(idx)
         r=mappedIdx.row()
-        ## print "row=%d mapped row=%d" %(idx.row(), r)
         h=self.header[c]
         if c==0 and self.checkable:
             self.manageCheckBoxes()
@@ -268,7 +270,7 @@ class mainWindow(QMainWindow):
             # case du propriétaire
             self.editOwner(mappedIdx)
         elif "device-mount-paths" in h:
-            cmd=u"nautilus '%s'" %idx.data().toString ()
+            cmd="nautilus '%s'" %idx.data().toString ()
             subprocess.call(cmd, shell=True)
         elif "device-size" in h:
             mount=idx.model().partition(idx).mountPoint()
@@ -279,7 +281,7 @@ class mainWindow(QMainWindow):
         else:
             QMessageBox.warning(None,
                                 QApplication.translate("Dialog","Double-clic non pris en compte",None, QApplication.UnicodeUTF8),
-                                QApplication.translate("Dialog","pas d'action pour l'attribut %1",None, QApplication.UnicodeUTF8).arg(h))
+                                QApplication.translate("Dialog","pas d'action pour l'attribut {a}",None, QApplication.UnicodeUTF8).format(a=h))
 
     def manageCheckBoxes(self):
         """
@@ -299,8 +301,9 @@ class mainWindow(QMainWindow):
             path=qApp.diskData[rowOrDev][self.header.index("1device-mount-paths")]
         else:
             path=rowOrDev
-        cmd =u"df '%s'" %path
-        dfOutput=subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0].split("\n")[-2]
+        cmd ="df '%s'" %path
+        dfOutput=subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0]
+        dfOutput=str(dfOutput.split(b"\n")[-2])
         m = re.match("(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+).*", dfOutput).groups()
         return m
 
@@ -331,7 +334,7 @@ class mainWindow(QMainWindow):
         Édition du propriétaire d'une clé.
         @param idx un QModelIndex qui pointe sur le propriétaire d'une clé
         """
-        student=u"%s" %self.tm.data(idx,Qt.DisplayRole).toString()
+        student="%s" %self.tm.data(idx,Qt.DisplayRole).toString()
         ownedUsbDisk.editRecord(self.diskFromOwner(student), hint=student)
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
         qApp.diskData=other
@@ -354,7 +357,7 @@ class mainWindow(QMainWindow):
             msg=self.namesEmptyTip
         self.ui.namesButton.setIcon(icon)
         self.ui.namesButton.setToolTip(msg)
-        self.ui.namesButton.setStatusTip(msg.remove("<br />"))
+        self.ui.namesButton.setStatusTip(msg.replace("<br />",""))
         
     def updateButtons(self):
         """
@@ -373,6 +376,11 @@ class mainWindow(QMainWindow):
                        self.ui.delButton,
                        self.ui.umountButton):
             button.setEnabled(active)
+        #modifie l'icone copyfrom/movefrom
+        if self.mv:
+            self.ui.fromButton.setIcon(self.movefromIcon)
+        else:
+            self.ui.fromButton.setIcon(self.copyfromIcon)
         # l'état du redoButton dépend de plusieurs facteurs
         # si un thread au moins est en cours, on y affiche un STOP actif
         # sinon on y met l'icône de lastCommand, et celle-ci sera active
@@ -416,7 +424,7 @@ class mainWindow(QMainWindow):
         d=chooseInSticks.chooseDialog(self, titre1, titre2)
         ok = d.exec_()
         if ok:
-            pathList=map(lambda x: u"%s" %x, d.pathList())
+            pathList=d.pathList()
             buttons=QMessageBox.Ok|QMessageBox.Cancel
             defaultButton=QMessageBox.Cancel
             reply=QMessageBox.warning(
@@ -425,11 +433,11 @@ class mainWindow(QMainWindow):
                 QApplication.translate("Dialog","Etes-vous certain de vouloir effacer : "+"\n".join(pathList),None, QApplication.UnicodeUTF8),
                 buttons, defaultButton)
             if reply == QMessageBox.Ok:
-                cmd='t=usbThread.threadDeleteInUSB(p,%s,subdir="Travail", logfile="%s", parent=self.tm)' %(pathList,logFileName)
+                cmd="usbThread.threadDeleteInUSB(p,{paths},subdir='Travail', logfile='{log}', parent=self.tm)".format(paths=pathList,log=logFileName)
                 for p in qApp.diskData:
                     if not p.selected: continue # pas les médias désélectionnés
                     registerCmd(cmd,p)
-                    exec(compile(cmd,'<string>','exec'))
+                    t=eval(cmd)
                     t.setDaemon(True)
                     t.start()
                     self.oldThreads.add(t)
@@ -448,11 +456,11 @@ class mainWindow(QMainWindow):
         d=copyToDialog1.copyToDialog1(parent=self, workdir=self.workdir)
         d.exec_()
         if d.ok==True:
-            cmd='t=usbThread.threadCopyToUSB(p,%s,subdir="%s", logfile="%s", parent=self.tm)' %(d.selectedList(), self.workdir, logFileName)
+            cmd="usbThread.threadCopyToUSB(p,{selected},subdir='{subdir}', logfile='{logfile}', parent=self.tm)".format(selected=list(d.selectedList()), subdir=self.workdir, logfile=logFileName)
             for p in qApp.diskData:
                 if not p.selected: continue # pas les médias désélectionnés
                 registerCmd(cmd,p)
-                exec(compile(cmd,'<string>','exec'))
+                t=eval(cmd)
                 t.setDaemon(True)
                 t.start()
                 self.oldThreads.add(t)
@@ -470,16 +478,16 @@ class mainWindow(QMainWindow):
         """
         titre1=QApplication.translate("Dialog","Choix de fichiers à copier",None, QApplication.UnicodeUTF8)
         titre2=QApplication.translate("Dialog", "Choix de fichiers à copier depuis les baladeurs", None, QApplication.UnicodeUTF8)
-        ok=QApplication.translate("Dialog", "Choix de la destination ...", None, QApplication.UnicodeUTF8)
-        d=chooseInSticks.chooseDialog(self, title1=titre1, title2=titre2, ok=ok)
-        ok = d.exec_()
-        if not ok or len(d.pathList())==0 :
+        okPrompt=QApplication.translate("Dialog", "Choix de la destination ...", None, QApplication.UnicodeUTF8)
+        d=chooseInSticks.chooseDialog(self, title1=titre1, title2=titre2, okPrompt=okPrompt)
+        d.exec_()
+        if not d.ok :
             msgBox=QMessageBox.warning(None,
                                        QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
                                        QApplication.translate("Dialog","Veuillez choisir au moins un fichier",None, QApplication.UnicodeUTF8))
             return True
         # bon, alors c'est OK pour le choix des fichiers à envoyer
-        pathList=map(lambda x: u"%s" %x, d.pathList())
+        pathList=d.pathList()
         mp=d.selectedDiskMountPoint()
         initialPath=os.path.expanduser("~")
         destDir = QFileDialog.getExistingDirectory(
@@ -488,15 +496,15 @@ class mainWindow(QMainWindow):
             initialPath)
         if destDir and len(destDir)>0 :
             if self.mv:
-                cmd=u"""t=usbThread.threadMoveFromUSB(
-                           p,%s,subdir=self.workdir,
-                           rootPath="%s", dest="%s", logfile="%s",
-                           parent=self.tm)""" %(pathList, mp, destDir, logFileName)
+                cmd="""usbThread.threadMoveFromUSB(
+                           p,{paths},subdir=self.workdir,
+                           rootPath='{mp}', dest='{dest}', logfile='{log}',
+                           parent=self.tm)""".format(paths=pathList, mp=mp, dest=destDir, log=logFileName)
             else:
-                cmd=u"""t=usbThread.threadCopyFromUSB(
-                           p,%s,subdir=self.workdir,
-                           rootPath="%s", dest="%s", logfile="%s",
-                           parent=self.tm)""" %(pathList, mp, destDir, logFileName)
+                cmd="""usbThread.threadCopyFromUSB(
+                           p,{paths},subdir=self.workdir,
+                           rootPath='{mp}', dest='{dest}', logfile='{log}',
+                           parent=self.tm)""".format(paths=pathList, mp=mp, dest=destDir, log=logFileName)
                 
             for p in qApp.diskData:
                 if not p.selected: continue # pas les médias désélectionnés
@@ -506,7 +514,7 @@ class mainWindow(QMainWindow):
                 # inconvénient : ça crée quelquefois des sous-répertoires
                 # vides inutiles dans le répertoire de destination.
                 registerCmd(cmd,p)
-                exec(compile(cmd,'<string>','exec'))
+                t=eval(cmd)
                 t.setDaemon(True)
                 t.start()
                 self.oldThreads.add(t)
@@ -538,16 +546,16 @@ class mainWindow(QMainWindow):
                 if thread.isAlive():
                     try:
                         thread._Thread__stop()
-                        print str(thread.getName()) + ' is terminated'
+                        print (str(thread.getName()) + ' is terminated')
                     except:
-                        print str(thread.getName()) + ' could not be terminated'
+                        print (str(thread.getName()) + ' could not be terminated')
         else:
             if lastCommand==None:
                 return
             if QMessageBox.question(
                 None,
                 QApplication.translate("Dialog","Réitérer la dernière commande",None, QApplication.UnicodeUTF8),
-                QApplication.translate("Dialog","La dernière commande était<br>%1<br>Voulez-vous la relancer avec les nouveaux baladeurs ?",None, QApplication.UnicodeUTF8).arg(lastCommand))==QMessageBox.Cancel:
+                QApplication.translate("Dialog","La dernière commande était<br>{cmd}<br>Voulez-vous la relancer avec les nouveaux baladeurs ?",None, QApplication.UnicodeUTF8).format(cmd=lastCommand))==QMessageBox.Cancel:
                 return
             for p in qApp.diskData:
                 if p.owner in pastCommands[lastCommand] : continue
@@ -592,13 +600,13 @@ class mainWindow(QMainWindow):
                 if p in qApp.diskData.disks[d] and p.selected:
                     # démontage de toutes les partitions du même disque parent
                     for partition in qApp.diskData.disks[d]:
-                        devfile=partition.getProp("device-file-by-id")
+                        devfile=partition.getProp("device-file-by-path")
                         if isinstance(devfile, dbus.Array):
                             devfile=devfile[0]
                             if partition.isMounted():
                                 subprocess.call("udisks --unmount %s" %devfile, shell=True)
                     # détachement du disque parent
-                    devfile_disk=d.getProp("device-file-by-id")
+                    devfile_disk=d.getProp("device-file-by-path")
                     if isinstance(devfile_disk, dbus.Array):
                         devfile_disk=devfile_disk[0]
                     subprocess.call("udisks --detach %s" %devfile_disk, shell=True)
@@ -716,9 +724,9 @@ class usbTableModel(QAbstractTableModel):
         @param cmd la commande shell effectuée sur ce baladeur
         """
         global activeThreads, pastCommands, lastCommand
-        owner=u"%s" %owner
+        owner="%s" %owner
         owner=owner.encode("utf-8")
-        if activeThreads.has_key(owner):
+        if owner in activeThreads:
             activeThreads[owner].append(cmd)
         else:
             activeThreads[owner]=[cmd]
@@ -732,9 +740,9 @@ class usbTableModel(QAbstractTableModel):
         @param cmd la commande shell effectuée sur ce baladeur
         """
         global activeThreads, pastCommands, lastCommand
-        owner=u"%s" %owner
+        owner="%s" %owner
         owner=owner.encode("utf-8")
-        if activeThreads.has_key(owner):
+        if owner in activeThreads:
             cmd0=activeThreads[owner].pop()
             if cmd0 in cmd:
                 msg=cmd.replace(cmd0,"")+"\n"
@@ -742,12 +750,11 @@ class usbTableModel(QAbstractTableModel):
                 logFile.write(msg)
                 logFile.close()
             else:
-                raise Exception, (u"mismatched commands\n%s\n%s" %(cmd,cmd0)).encode("utf-8")
+                raise Exception(("mismatched commands\n%s\n%s" %(cmd,cmd0)))
             if len(activeThreads[owner])==0:
                 activeThreads.pop(owner)
         else:
-            raise Exception, "End of command without a begin."
-        ## print "dans tableModel, popCmd", activeThreads
+            raise Exception("End of command without a begin.")
         self.updateOwnerColumn()
         if len(activeThreads)==0 :
             self.pere.updateButtons()
@@ -900,9 +907,9 @@ class UsbDiskDelegate(QStyledItemDelegate):
         rect1.translate(h,0)
         rect1.setSize(QSize(w-h,h))
         QApplication.style().drawItemText (painter, rect1, Qt.AlignLeft+Qt.AlignVCenter, option.palette, True, text)
-        QApplication.style().drawItemText (painter, rect0, Qt.AlignCenter, option.palette, True, QString("O"))
-        text=(u"%s" %text).encode("utf-8")
-        if activeThreads.has_key(text):
+        QApplication.style().drawItemText (painter, rect0, Qt.AlignCenter, option.palette, True, "O")
+        text=("%s" %text).encode("utf-8")
+        if text in activeThreads:
             QApplication.style().drawItemPixmap (painter, rect0, Qt.AlignCenter, self.busyPixmap)
         else:
             QApplication.style().drawItemPixmap (painter, rect0, Qt.AlignCenter, self.okPixmap)
