@@ -23,6 +23,8 @@ licence_en="""
 """
 
 licence['en']=licence_en
+dependences="python3-dbus python3-dbus.mainloop.qt"
+python3safe="True"
 
 import dbus, subprocess, os.path, re, time
 from PyQt4.QtGui import *
@@ -52,7 +54,7 @@ class uDisk:
         self.device_prop = dbus.Interface(self.device, "org.freedesktop.DBus.Properties")
         self.selected=True
         self.checkable=checkable
-        self.stickid=unicode(self.getProp("drive-serial"))
+        self.stickid=self.getProp("drive-serial")
         self.uuid=self.getProp("id-uuid")
         self.fatuuid=None  # pour l'uuid de la première partion vfat
         self.firstFat=None # poignée de la première partition vfat
@@ -82,10 +84,10 @@ class uDisk:
     def uniqueId(self):
         """
         renvoie un identifiant unique. Dans cette classe, cette fonction
-        est synonyme de getFatUuid
-        @return un identifiant supposément unique
+        est synonyme de file()
+        @return un identifiant unique, garanti par le système de fichiers
         """
-        return self.getFatUuid()
+        return self.file()
         
     def headers(checkable=False,locale="C"):
         """
@@ -98,7 +100,7 @@ class uDisk:
         @return une liste de titres de colonnes
         """
         if checkable:
-            result=uDisk._specialItems.keys()+ uDisk._itemNames.keys()
+            result= list(uDisk._specialItems.keys())+ list(uDisk._itemNames.keys())
             return sorted(result)
         else:
             return sorted(uDisk._itemNames.keys())
@@ -152,9 +154,9 @@ class uDisk:
         @return un nom valide dans le système de fichiers, pour accéder
         à l'instance.
         """
-        fileById=self.getProp("device-file-by-id")
-        if isinstance(fileById, dbus.Array): fileById=fileById[0]
-        return fileById
+        fileByPath=self.getProp("device-file-by-path")
+        if isinstance(fileByPath, dbus.Array): fileByPath=fileByPath[0]
+        return fileByPath
     
     def mountPoint(self):
         """
@@ -199,6 +201,7 @@ class uDisk:
         prefix="\n"+" "*indent
         r=""
         props=["device-file-by-id",
+               "device-file-by-path",
                "device-mount-paths",
                "device-is-partition-table",
                "partition-table-count",
@@ -314,7 +317,7 @@ class uDisk:
         leftTries=5
         while len(mount_paths)==0 and leftTries >0:
             leftTries = leftTries - 1
-            path=self.getProp("device-file-by-id")
+            path=self.getProp("device-file-by-path")
             if isinstance(path,dbus.Array) and len(path)>0:
                 path=path[0]
                 subprocess.call("udisks --mount %s > /dev/null" %path,shell=True)
@@ -326,7 +329,7 @@ class uDisk:
             else:
                 time.sleep(0.5)
         if leftTries==0:
-            raise Exception, "Could not mount the VFAT after 5 tries." 
+            raise Exception ("Could not mount the VFAT after 5 tries.")
         else:
             return mount_paths[0]
 
@@ -358,7 +361,6 @@ class Available:
         @param diskClass la classe de disques à créer
         @param diskDict un dictionnaire des disque maintenu par deviceListener
         """
-        ## print "GRRRR should use diskDict=", diskDict
         self.checkable=checkable
         self.access=access
         self.bus = dbus.SystemBus()
@@ -424,7 +426,7 @@ class Available:
         @return vrai si le uDisk ud est dans la collection
         """
         for k in self.disks.keys():
-            if k.getProp("device-file-by-id")==ud.getProp("device-file-by-id"): return True
+            if k.getProp("device-file-by-path")==ud.getProp("device-file-by-path"): return True
         return False
     
     def summary(self):
@@ -527,5 +529,5 @@ class Available:
 
 if __name__=="__main__":
     machin=Available()
-    print machin
+    print (machin)
     
