@@ -5,7 +5,7 @@ licenceEn="""
     file usbThread.py
     this file is part of the project scolasync
     
-    Copyright (C) 2010 Georges Khaznadar <georgesk@ofset.org>
+    Copyright (C) 2010-2012 Georges Khaznadar <georgesk@ofset.org>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,11 +21,21 @@ licenceEn="""
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+python3safe=True
+
 import subprocess, threading, re, os, os.path, shutil, time, glob, shlex
 from PyQt4.QtCore import *
 
 _threadNumber=0
 
+def ensureDirExists(destpath):
+    """
+    force l'existence d'un répertoire, récursivement si nécessaire
+    @param destpath le chemin de ce répertoire
+    """
+    os.path.isdir(destpath) or os.makedirs(destpath, mode=0o755)
+    return
+
 class ThreadRegister:
     """
     Une classe pour tenir un registre des threads concernant les baladeurs.
@@ -134,7 +144,7 @@ class abstractThreadUSB(threading.Thread):
         threading.Thread.__init__(self,target=self.toDo,
                                   args=(ud, fileList, subdir, dest, logfile),
                                   name=_threadName(ud))        
-        self.cmd=u"echo This is an abstract method, don't call it"
+        self.cmd="echo This is an abstract method, don't call it"
         self.ud=ud
         ud.threadRunning=True
         self.fileList=fileList
@@ -172,7 +182,7 @@ class abstractThreadUSB(threading.Thread):
 
         try:
             os.makedirs(dst)
-        except OSError, err:
+        except OSError as err:
             pass
         for name in names:
             if name in ignored_names:
@@ -196,11 +206,15 @@ class abstractThreadUSB(threading.Thread):
                     if not errors and erase:
                         os.unlink(srcname)
                 # XXX What about devices, sockets etc.?
-            except (IOError, os.error), why:
+            except IOError as why:
                 errors.append((srcname, dstname, str(why)))
-            # catch the Error from the recursive copytree so that we can
-            # continue with other files
-            except Exception, err:
+                # catch the Error from the recursive copytree so that we can
+                # continue with other files
+            except os.error as why:
+                errors.append((srcname, dstname, str(why)))
+                # catch the Error from the recursive copytree so that we can
+                # continue with other files
+            except Exception as err:
                 errors.extend(err.args[0])
         return errors
 
@@ -255,7 +269,7 @@ class threadCopyToUSB(abstractThreadUSB):
           d'exécution
         """
         abstractThreadUSB.__init__(self,ud, fileList, subdir, dest=None, logfile=logfile, parent=parent)
-        self.cmd=u'mkdir -p "{toDir}"; cp -R {fromFile} "{toDir}"'
+        self.cmd='mkdir -p "{toDir}"; cp -R {fromFile} "{toDir}"'
 
     def threadType(self):
         """
@@ -278,18 +292,21 @@ class threadCopyToUSB(abstractThreadUSB):
         while subdir[0]=='/':
             subdir=subdir[1:]
         destpath=os.path.join(ud.ensureMounted(),ud.visibleDir(),subdir)
+        ensureDirExists(destpath)
+        # boucle de copie
         for f in fileList:
             cmd="copying %s to %s" %(f, destpath)
             if self.parent:
                 self.parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
             destpath1=os.path.join(destpath, os.path.basename(f))
+            # copie d'arbre si on copie un répertoire, ou de simple fichier
             if os.path.isdir(f):
                 errors=self.copytree(f, destpath1)
             else:
                 errors=[]
                 try:
                     shutil.copy2(f, destpath1)
-                except Exceptio, err:
+                except Exception as err:
                     errors.extend((f, destpath1, str(err)))
                     
             msg="[%s] " %_date()
@@ -325,7 +342,6 @@ class threadCopyFromUSB(abstractThreadUSB):
         abstractThreadUSB.__init__(self,ud, fileList, subdir, dest=dest,
                                    logfile=logfile, parent=parent)
         self.rootPath=rootPath
-        self.cmd=u'mkdir -p "{toPath}"; cp -R {fromPath} "{toPath}"'
 
     def toDo(self, ud, fileList, subdir, dest, logfile):
         """
@@ -338,15 +354,16 @@ class threadCopyFromUSB(abstractThreadUSB):
         @param logfile un fichier de journalisation
         @param subdir le sous-répertoire de la clé USB où faire la copie
         """
-        
         for f in fileList:
             ## prend le fichier ou le répertoire sur le disque courant
             fromPath=os.path.join(ud.ensureMounted(), f)
             owner=ud.ownerByDb()
             ## personnalise le nom de la destination
-            newName=u"%s_%s" %(owner,os.path.dirname(f))
+            newName="%s_%s" %(owner,os.path.dirname(f))
             ## calcule le point de copie et le répertoire à créer s'il le faut
             toPath=os.path.join(dest,newName)
+            # crée le répertoire cible si nécessaire
+            ensureDirExists(toPath)
             cmd="copying %s to %s" %(fromPath, toPath)
             if self.parent:
                 self.parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
@@ -357,7 +374,7 @@ class threadCopyFromUSB(abstractThreadUSB):
                 errors=[]
                 try:
                     shutil.copy2(fromPath, destpath1)
-                except Exception, err:
+                except Exception as err:
                     errors.extend((fromPath, destpath1, str(err)))
                     
             msg="[%s] " %_date()
@@ -393,7 +410,6 @@ class threadMoveFromUSB(abstractThreadUSB):
         abstractThreadUSB.__init__(self,ud, fileList, subdir, dest=dest,
                                    logfile=logfile, parent=parent)
         self.rootPath=rootPath
-        self.cmd=u'mkdir -p "{toPath}"; cp -R {fromPath} "{toPath}" && rm -rf {fromPath}'
 
     def toDo(self, ud, fileList, subdir, dest, logfile):
         """
@@ -412,9 +428,11 @@ class threadMoveFromUSB(abstractThreadUSB):
             fromPath=os.path.join(ud.ensureMounted(), f)
             owner=ud.ownerByDb()
             ## personnalise le nom de la destination
-            newName=u"%s_%s" %(owner,os.path.dirname(f))
+            newName="%s_%s" %(owner,os.path.dirname(f))
             ## calcule le point de copie et le répertoire à créer s'il le faut
             toPath=os.path.join(dest,newName)
+            # crée le répertoire cible si nécessaire
+            ensureDirExists(toPath)
             cmd="copying %s to %s" %(fromPath, toPath)
             if self.parent:
                 self.parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
@@ -423,14 +441,14 @@ class threadMoveFromUSB(abstractThreadUSB):
                 errors=self.copytree(fromPath, destpath1, erase=True)
                 try:
                     os.rmdir(fromPath)
-                except Exception, err:
+                except Exception as err:
                     errors.extend((fromPath, destpath1, str(err)))
             else:
                 errors=[]
                 try:
                     shutil.copy2(fromPath, destpath1)
                     os.unlink(fromPath)
-                except Exception, err:
+                except Exception as err:
                     errors.extend((fromPath, destpath1, str(err)))
                     
             msg="[%s] " %_date()
@@ -444,7 +462,7 @@ class threadMoveFromUSB(abstractThreadUSB):
             if self.parent:
                 self.parent.emit(SIGNAL("popCmd(QString, QString)"), ud.owner, msg)
             self.writeToLog(msg)
-            
+
 class threadDeleteInUSB(abstractThreadUSB):
     """
     Classe pour les threads effaçant des sous-arbres dans les clés USB
@@ -463,7 +481,6 @@ class threadDeleteInUSB(abstractThreadUSB):
         """
         abstractThreadUSB.__init__(self,ud, fileList, subdir, dest=None,
                                    logfile=logfile, parent=parent)
-        self.cmd=u'rm -rf {toDel}'
 
     def toDo(self, ud, fileList, subdir, dest, logfile):
         """
@@ -492,12 +509,12 @@ class threadDeleteInUSB(abstractThreadUSB):
                         for name in dirs:
                             os.rmdir(os.path.join(root, name))
                     os.rmdir(toDel)
-                except Exception, err:
+                except Exception as err:
                     errors.expand((toDel,str(err)))
             else:
                 try:
                     os.unlink(toDel)
-                except Exception, err:
+                except Exception as err:
                     errors.expand((toDel,str(err)))
             msg="[%s] " %_date()
             if not errors:
